@@ -1,24 +1,20 @@
 #' `FeatureHandler` factory for Google COVID-19 epidemic metrics
 #'
 #' @description
-#'   This function implements a `FeatureHandler` factory for Google COVID-19 epidemic metrics.
+#'   This function implements a `?FeatureHandler` factory for Google COVID-19 epidemic metrics.
 #'   This factory is used when defining the `DiseasystoreGoogleCovid19` feature store.
 #' @param google_pattern (`character`)\cr
 #'   A regexp pattern that matches Google's naming of the metric in "by-age.csv.gz".
 #' @param out_name (`character`)\cr
 #'   A the name to store the metric in our our feature store.
 #' @return
-#'   A new instance of `FeatureHandler` [R6][R6::R6Class] class corresponding to the epidemic metric.
+#'   A new instance of `?FeatureHandler` [R6][R6::R6Class] class corresponding to the epidemic metric.
 #' @importFrom rlang .data
 #' @noRd
 google_covid_19_metric <- function(google_pattern, out_name) {                                                          # nocov start
   FeatureHandler$new(
-    compute = function(start_date, end_date, slice_ts, source_conn) {
-      coll <- checkmate::makeAssertCollection()
-      checkmate::assert_date(start_date, lower = as.Date("2020-01-01"), add = coll)
-      checkmate::assert_date(end_date,   upper = as.Date("2022-09-15"), add = coll)
-      checkmate::assert_character(source_conn, len = 1, add = coll)
-      checkmate::reportAssertions(coll)
+    compute = function(start_date, end_date, slice_ts, source_conn, ...) {
+      checkmate::assert_character(source_conn, len = 1)
 
       # Load and parse
       data <- source_conn_path(source_conn, "by-age.csv") |>
@@ -54,6 +50,8 @@ google_covid_19_metric <- function(google_pattern, out_name) {
 #'     target_conn = DBI::dbConnect(RSQLite::SQLite())
 #'   )
 #'
+#*   ds$available_features
+#'
 #'   rm(ds)
 #' @return
 #'   A new instance of the `DiseasystoreGoogleCovid19` [R6][R6::R6Class] class.
@@ -81,16 +79,15 @@ DiseasystoreGoogleCovid19 <- R6::R6Class(
       "min_temperature" = "google_covid_19_min_temperature",
       "max_temperature" = "google_covid_19_max_temperature"
     ),
+    .observables_regex = r"{^n_(?=\w)|(?<=\w)_temperature$}",
     .label = "Google COVID-19",
 
+    .min_start_date = as.Date("2020-01-01"),
+    .max_end_date = as.Date("2022-09-15"), # Data source is no longer actively updated
 
     google_covid_19_population = FeatureHandler$new(
-      compute = function(start_date, end_date, slice_ts, source_conn) {
-        coll <- checkmate::makeAssertCollection()
-        checkmate::assert_date(start_date, lower = as.Date("2020-01-01"), add = coll)
-        checkmate::assert_date(end_date,   upper = as.Date("2022-09-15"), add = coll)
-        checkmate::assert_character(source_conn, len = 1, add = coll)
-        checkmate::reportAssertions(coll)
+      compute = function(start_date, end_date, slice_ts, source_conn, ...) {
+        checkmate::assert_character(source_conn, len = 1)
 
         # Load and parse
         out <- source_conn_path(source_conn, "demographics.csv") |>
@@ -114,12 +111,8 @@ DiseasystoreGoogleCovid19 <- R6::R6Class(
     ),
 
     google_covid_19_index = FeatureHandler$new(
-      compute = function(start_date, end_date, slice_ts, source_conn) {
-        coll <- checkmate::makeAssertCollection()
-        checkmate::assert_date(start_date, lower = as.Date("2020-01-01"), add = coll)
-        checkmate::assert_date(end_date,   upper = as.Date("2022-09-15"), add = coll)
-        checkmate::assert_character(source_conn, len = 1, add = coll)
-        checkmate::reportAssertions(coll)
+      compute = function(start_date, end_date, slice_ts, source_conn, ...) {
+        checkmate::assert_character(source_conn, len = 1)
 
         # Load and parse
         out <- source_conn_path(source_conn, "index.csv") |>
@@ -154,13 +147,8 @@ DiseasystoreGoogleCovid19 <- R6::R6Class(
     google_covid_19_ventilator = google_covid_19_metric("ventilator_patients", "n_ventilator"),
 
     google_covid_19_age_group = FeatureHandler$new(
-      compute = function(start_date, end_date, slice_ts, source_conn) {
-
-        coll <- checkmate::makeAssertCollection()
-        checkmate::assert_date(start_date, lower = as.Date("2020-01-01"), add = coll)
-        checkmate::assert_date(end_date,   upper = as.Date("2022-09-15"), add = coll)
-        checkmate::assert_character(source_conn, len = 1, add = coll)
-        checkmate::reportAssertions(coll)
+      compute = function(start_date, end_date, slice_ts, source_conn, ...) {
+        checkmate::assert_character(source_conn, len = 1)
 
         # Load and parse
         out <- source_conn_path(source_conn, "by-age.csv") |>
@@ -199,7 +187,8 @@ DiseasystoreGoogleCovid19 <- R6::R6Class(
         # And finally copy to the DB
         out <- age_bin_map |>
           dplyr::rename("key_age_bin" = "age_bin", "key_location" = "location_key") |>
-          dplyr::mutate("valid_from" = as.Date("2020-01-01"), "valid_until" = as.Date(NA))
+          dplyr::mutate("valid_from" = as.Date("2020-01-01"), "valid_until" = as.Date(NA)) |>
+          dplyr::ungroup()
 
         return(out)
       },
@@ -208,12 +197,8 @@ DiseasystoreGoogleCovid19 <- R6::R6Class(
 
 
     google_covid_19_min_temperature  = FeatureHandler$new(
-      compute = function(start_date, end_date, slice_ts, source_conn) {
-        coll <- checkmate::makeAssertCollection()
-        checkmate::assert_date(start_date, lower = as.Date("2020-01-01"), add = coll)
-        checkmate::assert_date(end_date,   upper = as.Date("2022-09-15"), add = coll)
-        checkmate::assert_character(source_conn, len = 1, add = coll)
-        checkmate::reportAssertions(coll)
+      compute = function(start_date, end_date, slice_ts, source_conn, ...) {
+        checkmate::assert_character(source_conn, len = 1)
 
         # Load and parse
         out <- source_conn_path(source_conn, "weather.csv") |>
@@ -232,12 +217,8 @@ DiseasystoreGoogleCovid19 <- R6::R6Class(
     ),
 
     google_covid_19_max_temperature  = FeatureHandler$new(
-      compute = function(start_date, end_date, slice_ts, source_conn) {
-        coll <- checkmate::makeAssertCollection()
-        checkmate::assert_date(start_date, lower = as.Date("2020-01-01"), add = coll)
-        checkmate::assert_date(end_date,   upper = as.Date("2022-09-15"), add = coll)
-        checkmate::assert_character(source_conn, len = 1, add = coll)
-        checkmate::reportAssertions(coll)
+      compute = function(start_date, end_date, slice_ts, source_conn, ...) {
+        checkmate::assert_character(source_conn, len = 1)
 
         # Load and parse
         out <- source_conn_path(source_conn, "weather.csv") |>
@@ -276,19 +257,19 @@ DiseasystoreGoogleCovid19 <- R6::R6Class(
 
         # If no spatial stratification is requested, use the largest available per country
         filter_level <- self$get_feature("country_id", start_date, end_date) |>
-          dplyr::group_by(country_id) |>
-          dplyr::slice_min(aggregation_level) |>
+          dplyr::group_by(.data$country_id) |>
+          dplyr::slice_min(.data$aggregation_level) |>
           dplyr::ungroup() |>
-          dplyr::select(key_location)
+          dplyr::select("key_location")
 
         return(dplyr::inner_join(.data, filter_level, by = "key_location", copy = TRUE))
 
       } else if (purrr::some(stratification_features, ~ . %in% c("country_id", "country"))) {
-        return(.data |> dplyr::filter(key_location == country_id))
+        return(.data |> dplyr::filter(.data$key_location == .data$country_id))
       } else if (purrr::some(stratification_features, ~ . %in% c("region_id", "region"))) {
-        return(.data |> dplyr::filter(key_location == region_id))
+        return(.data |> dplyr::filter(.data$key_location == .data$region_id))
       } else if (purrr::some(stratification_features, ~ . %in% c("subregion_id", "subregion"))) {
-        return(.data |> dplyr::filter(key_location == subregion_id))
+        return(.data |> dplyr::filter(.data$key_location == .data$subregion_id))
       } else {
         stop("Edge case detected in $key_join_filter() (DiseasyStoreGoogleCovid19)")
       }
