@@ -13,9 +13,11 @@
 #'
 #'   DBI::dbDisconnect(conn)
 #' @export
-drop_diseasystore <- function(pattern = NULL,
-                              schema = diseasyoption("target_schema"),
-                              conn = SCDB::get_connection()) {
+drop_diseasystore <- function(
+  pattern = NULL,
+  schema = diseasyoption("target_schema", namespace = "diseasystore"),
+  conn = SCDB::get_connection()
+) {
 
   coll <- checkmate::makeAssertCollection()
   checkmate::assert_character(pattern, null.ok = TRUE, add = coll)
@@ -51,8 +53,7 @@ drop_diseasystore <- function(pattern = NULL,
 
   # Use regex to match tables to delete
   tables_to_delete <- tables |>
-    dplyr::filter(stringr::str_starts(.data$db_table_id, paste0("^", ds_table_pattern))) |>
-    dplyr::select(!"db_table_id")
+    dplyr::filter(stringr::str_starts(.data$db_table_id, paste0("^", ds_table_pattern)))
 
   # Ensure schema is the same for all identified tables (if not, we have unwanted ambiguity)
   if (length(unique(dplyr::pull(tables_to_delete, "schema"))) > 1) {
@@ -61,10 +62,14 @@ drop_diseasystore <- function(pattern = NULL,
 
   # Check if the table "logs" is in the list of tables to delete, if yes, all tables must be deleted.
   if (purrr::some(tables_to_delete$table, ~ endsWith(., ".logs")) &&
-        !identical(tables_to_delete, SCDB::get_tables(conn, paste0("^", ds_context)))) {
+        !identical(tables_to_delete, dplyr::filter(tables, stringr::str_starts(.data$db_table_id, ds_context)))) {
     stop(glue::glue("'{schema}.logs' set to delete. Can only delete if entire feature store is dropped!"))
   }
 
+  # Drop the combined column to make it convertible to id
+  tables_to_delete <- tables_to_delete |>
+    dplyr::select(!"db_table_id")
+
   # Delete tables
   if (nrow(tables_to_delete) > 0) {
     tables_to_delete |>
